@@ -64,17 +64,20 @@ def format_coco_file(imgdir, annotations, train_assets, test_assets):
         else:
             shape["label"] = find_category(annotations, shape["category_id"])
             formatted_annotations[shape["image_id"]] = [shape]
+
     for image in annotations["images"]:
-        image["path"] = os.path.join(imgdir, image["file_name"])
+        image_filename = image["file_name"]
+        image_path = os.path.join(imgdir, image_filename)
+        if not os.path.isfile(image_path):
+            continue
         tmp = image.copy()
-        try:
+        tmp["path"] = image_path
+        if image["id"] in formatted_annotations:
             tmp["annotations"] = formatted_annotations[image["id"]]
-            if image["file_name"] in train_assets_fname:
+            if image_filename in train_assets_fname:
                 formatted_file_train["images"].append(tmp)
-            if image["file_name"] in test_assets_fname:
+            if image_filename in test_assets_fname:
                 formatted_file_test["images"].append(tmp)
-        except KeyError:
-            pass
     return formatted_file_train, formatted_file_test
 
 
